#!/bin/bash

set -e
set -x

check_link_status() {
    local iface="$1"
    ethtool "$iface" 2>/dev/null | grep -q "Link detected: yes"
}

check_speed() {
    local iface="$1"
    local speed=$(ethtool "$iface" 2>/dev/null | grep "Speed:" | awk '{print $2}' | sed 's/Mb\/s//')
    [[ "$speed" == "1000" ]]
}

ipaddr="192.168.30.100"
macaddr=""

if [ -f "/opt/eswin/bin/station_status" ]; then
  status_content=$(cat "/opt/eswin/bin/station_status" 2>/dev/null | tr -d '[:space:]')
  if [ "$status_content" = "station:1" ]; then
    iface="end0"
  else
    iface="end1"
  fi
else
  iface="end0"
fi

echo "Using network interface: $iface"

while ! ethtool "$iface" | grep -q "Link detected: yes"; do
    echo "waiting for $iface link up..."
    sleep 2
done

if ! check_speed "$iface"; then
    echo "$iface: Negotiated speed is NOT 1000Mb/s, test failed"
    exit 1
fi
echo "$iface: Negotiated speed is 1000Mb/s"

gateway="$(echo $ipaddr | awk -F'.' '{print $1"."$2"."$3".1"}')"

systemctl daemon-reload
echo 3 > /proc/sys/kernel/printk

if [ -n "$macaddr" ]; then
    echo "Changing MAC address of $iface to $macaddr"
    ip link set dev "$iface" down
    ip link set dev "$iface" address "$macaddr"
    ip link set dev "$iface" up
fi

nmcli connection delete "static-end0" || true
nmcli connection delete "static-end1" || true

nmcli connection add type ethernet ifname "$iface" con-name "static-$iface" ip4 "${ipaddr}/24" gw4 "${gateway}"

nmcli connection up "static-$iface"
